searchData={"items":[{"type":"module","title":"Sippet","doc":"Holds the Sippet stack.\n\nNetwork transport protocols should be registered during initialization:\n\n    def init(_) do\n      Sippet.register_transport(:udp, false)\n      ...\n    end\n\nMessages are dispatched to transports by sending the following message:\n\n    send(pid, {:send_message, message, host, port, transaction})\n\nWhenever a message is received by a transport, the function\n`Sippet.handle_transport_message` is called, which will validate and route\nmessages through the transaction layer or send directly to the core.","ref":"Sippet.html"},{"type":"function","title":"Sippet.register_core/2","doc":"Registers the stack core.","ref":"Sippet.html#register_core/2"},{"type":"function","title":"Sippet.register_transport/3","doc":"Registers a transport for a given protocol.","ref":"Sippet.html#register_transport/3"},{"type":"function","title":"Sippet.reliable?/2","doc":"Verifies if the transport protocol used to send the given message is\nreliable.","ref":"Sippet.html#reliable?/2"},{"type":"function","title":"Sippet.send/2","doc":"Sends a message (request or response) using transactions if possible.\n\nRequests of method `:ack` is sent directly to the transport layer.\n\nA `Sippet.Transactions.Client` is created for requests to handle client\nretransmissions, when the transport presumes it, and match response\nretransmissions, so the `Sippet.Core` doesn't get retransmissions other than\n200 OK for `:invite` requests.\n\nIn case of success, returns `:ok`.","ref":"Sippet.html#send/2"},{"type":"function","title":"Sippet.sigil_K/2","doc":"Handles the sigil `~K`.\n\nIt returns a client or server transaction key depending on the number of\nparameters passed.","ref":"Sippet.html#sigil_K/2"},{"type":"function","title":"Examples - Sippet.sigil_K/2","doc":"iex> import Sippet, only: [sigil_K: 2]\n\n    iex> Sippet.Transactions.Client.Key.new(\"z9hG4bK230f2.1\", :invite)\n    ~K[z9hG4bK230f2.1|:invite]\n\n    iex> ~K[z9hG4bK230f2.1|INVITE]\n    ~K[z9hG4bK230f2.1|:invite]\n\n    iex> Sippet.Transactions.Server.Key.new(\"z9hG4bK74b21\", :invite, {\"client.biloxi.example.com\", 5060})\n    ~K[z9hG4bK74b21|:invite|client.biloxi.example.com:5060]\n\n    iex> ~K[z9hG4bK74b21|INVITE|client.biloxi.example.com:5060]\n    ~K[z9hG4bK74b21|:invite|client.biloxi.example.com:5060]","ref":"Sippet.html#sigil_K/2-examples"},{"type":"function","title":"Sippet.terminate/2","doc":"Terminates a client or server transaction forcefully.\n\nThis function is not generally executed by entities; there is a single case\nwhere it is fundamental, which is when a client transaction is in proceeding\nstate for a long time, and the transaction has to be finished forcibly, or it\nwill never finish by itself.\n\nIf a transaction with such a key does not exist, it will be silently ignored.","ref":"Sippet.html#terminate/2"},{"type":"type","title":"Sippet.client_key/0","doc":"A client transaction identifier","ref":"Sippet.html#t:client_key/0"},{"type":"type","title":"Sippet.reason/0","doc":"An network error that occurred while sending a message","ref":"Sippet.html#t:reason/0"},{"type":"type","title":"Sippet.request/0","doc":"A SIP message request","ref":"Sippet.html#t:request/0"},{"type":"type","title":"Sippet.response/0","doc":"A SIP message response","ref":"Sippet.html#t:response/0"},{"type":"type","title":"Sippet.server_key/0","doc":"A server transaction identifier","ref":"Sippet.html#t:server_key/0"},{"type":"type","title":"Sippet.sippet/0","doc":"Sippet identifier","ref":"Sippet.html#t:sippet/0"},{"type":"behaviour","title":"Sippet.Core","doc":"A behaviour module for implementing the `Sippet.Core`.\n\nThe `Sippet.Core` designates a particular type of SIP entity, i.e., specific\nto either a stateful or stateless proxy, a user agent or registrar.","ref":"Sippet.Core.html"},{"type":"callback","title":"Sippet.Core.receive_error/2","doc":"Receives an error from the server or client transaction.\n\nThe function `receive_error/2` is called from the client or server\ntransaction process created when sending or receiving requests.","ref":"Sippet.Core.html#c:receive_error/2"},{"type":"callback","title":"Sippet.Core.receive_request/2","doc":"Receives a new incoming request from a remote host, or ACK.\n\nThe `server_key` indicates the name of the transaction created when\nthe request was received. If it is an ACK, then the `server_key` is\n`nil`.\n\nThe function `receive_request/2` is called from the server transaction\nprocess when the parameter `server_key` is not `nil`, and from the\ntransport process (possibly a `poolboy` worker process), when the\n`server_key` is `nil`.","ref":"Sippet.Core.html#c:receive_request/2"},{"type":"callback","title":"Sippet.Core.receive_response/2","doc":"Receives a response for a sent request.\n\nThe `client_key` indicates the name of the transaction created when\nthe request was sent using `Sippet.Transactions.send_request/1`.\n\nThe function `receive_response/2` is called from the client transaction\nprocess when the parameter `client_key` is not `nil`, and from the\ntransport process (possibly a `poolboy` worker process), when the\n`client_key` is `nil`.","ref":"Sippet.Core.html#c:receive_response/2"},{"type":"module","title":"Sippet.DigestAuth","doc":"Implements the Digest authentication protocol.","ref":"Sippet.DigestAuth.html"},{"type":"function","title":"Sippet.DigestAuth.make_request/4","doc":"Adds an `Authorization` or `Proxy-Authorization` header for a request after\nreceiving a 401 or 407 response. `CSeq` must be updated after calling this\nfunction.\n\n`incoming_response` must be an incoming 401/407 response containing a single\nchallenge header (either Proxy-Authenticate or WWW-Authenticate) and\n`outgoing_request` is the last request sent to the server. The passed\nfunction receives the realm and should return `{:ok, username, password}` or\n`{:error, reason}`.","ref":"Sippet.DigestAuth.html#make_request/4"},{"type":"function","title":"Sippet.DigestAuth.make_response/4","doc":"Generates a response containing `WWW-Authenticate` or `Proxy-Authenticate`\nheader for an incoming request. Use this function to answer to a request with\na 401 or 407 response.\n\nA new `nonce' will be generated to be used by the client in its response,\nbut will expire after the time configured indicated in `nonce_timeout'.","ref":"Sippet.DigestAuth.html#make_response/4"},{"type":"type","title":"Sippet.DigestAuth.password/0","doc":"","ref":"Sippet.DigestAuth.html#t:password/0"},{"type":"type","title":"Sippet.DigestAuth.realm/0","doc":"","ref":"Sippet.DigestAuth.html#t:realm/0"},{"type":"type","title":"Sippet.DigestAuth.reason/0","doc":"","ref":"Sippet.DigestAuth.html#t:reason/0"},{"type":"type","title":"Sippet.DigestAuth.req_option/0","doc":"","ref":"Sippet.DigestAuth.html#t:req_option/0"},{"type":"type","title":"Sippet.DigestAuth.req_options/0","doc":"","ref":"Sippet.DigestAuth.html#t:req_options/0"},{"type":"type","title":"Sippet.DigestAuth.resp_option/0","doc":"","ref":"Sippet.DigestAuth.html#t:resp_option/0"},{"type":"type","title":"Sippet.DigestAuth.resp_options/0","doc":"","ref":"Sippet.DigestAuth.html#t:resp_options/0"},{"type":"type","title":"Sippet.DigestAuth.username/0","doc":"","ref":"Sippet.DigestAuth.html#t:username/0"},{"type":"module","title":"Sippet.Message","doc":"Message primitive for composing SIP messages.\nBuild a SIP message with the `Sippet.Message` struct.\n\n    request =\n      Sippet.Message.build_request(\"INVITE\", \"sip:joe@example.com\")\n      |> Sippet.Message.put_header(:to,\n          {\"\", Sippet.URI.parse!(\"sip:joe@example.com\"), %{}})\n      ...","ref":"Sippet.Message.html"},{"type":"function","title":"Sippet.Message.build_request/2","doc":"Returns a SIP request created from its basic elements.\n\nIf the `method` is a binary and is a known method, it will be converted to\na lowercase atom; otherwise, it will be stored as an uppercase string. If\n`method` is an atom, it will be just kept.\n\nIf the `request_uri` is a binary, it will be parsed as a `Sippet.URI` struct.\nOtherwise, if it's already a `Sippet.URI`, it will be stored unmodified.\n\nThe newly created struct has an empty header map, and the body is `nil`.","ref":"Sippet.Message.html#build_request/2"},{"type":"function","title":"Examples: - Sippet.Message.build_request/2","doc":"iex> req1 = Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    %Sippet.Message{body: nil, headers: %{},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}\n    iex> req2 = Sippet.Message.build_request(\"INVITE\", \"sip:foo@bar.com\")\n    iex> request_uri = Sippet.URI.parse!(\"sip:foo@bar.com\")\n    iex> req3 = Sippet.Message.build_request(\"INVITE\", request_uri)\n    iex> req1 == req2 and req2 == req3\n    true","ref":"Sippet.Message.html#build_request/2-examples"},{"type":"function","title":"Sippet.Message.build_response/1","doc":"Returns a SIP response created from its basic elements.\n\nThe `status` parameter can be a `Sippet.Message.StatusLine` struct or an\ninteger in the range `100..699` representing the SIP response status code.\nIn the latter case, a default reason phrase will be obtained from a default\nset; if there's none, then an exception will be raised.","ref":"Sippet.Message.html#build_response/1"},{"type":"function","title":"Examples: - Sippet.Message.build_response/1","doc":"iex> resp1 = Sippet.Message.build_response 200\n    %Sippet.Message{body: nil, headers: %{},\n     start_line: %Sippet.Message.StatusLine{reason_phrase: \"OK\", status_code: 200,\n      version: {2, 0}}, target: nil}\n    iex> status_line = Sippet.Message.StatusLine.new(200)\n    iex> resp2 = status_line |> Sippet.Message.build_response\n    iex> resp1 == resp2\n    true","ref":"Sippet.Message.html#build_response/1-examples"},{"type":"function","title":"Sippet.Message.build_response/2","doc":"Returns a SIP response with a custom reason phrase.\n\nThe `status_code` should be an integer in the range `100..699` representing\nthe SIP status code, and `reason_phrase` a binary representing the reason\nphrase text.\n\n    iex> Sippet.Message.build_response 400, \"Bad Lorem Ipsum\"\n    %Sippet.Message{body: nil, headers: %{},\n     start_line: %Sippet.Message.StatusLine{reason_phrase: \"Bad Lorem Ipsum\",\n      status_code: 400, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#build_response/2"},{"type":"function","title":"Sippet.Message.create_branch/0","doc":"Creates an unique local branch (72-bit random string, 7+12 characters long).","ref":"Sippet.Message.html#create_branch/0"},{"type":"function","title":"Example: - Sippet.Message.create_branch/0","doc":"Sippet.Message.create_branch\n    \"z9hG4bKuQpiub9h7fBb\"","ref":"Sippet.Message.html#create_branch/0-example"},{"type":"function","title":"Sippet.Message.create_call_id/0","doc":"Creates an unique Call-ID (120-bit random string, 20 characters long).","ref":"Sippet.Message.html#create_call_id/0"},{"type":"function","title":"Example - Sippet.Message.create_call_id/0","doc":"Sippet.create_call_id\n    \"NlV4TfQwkmPlNJkyHPpF\"","ref":"Sippet.Message.html#create_call_id/0-example"},{"type":"function","title":"Sippet.Message.create_tag/0","doc":"Creates a local tag (48-bit random string, 8 characters long).","ref":"Sippet.Message.html#create_tag/0"},{"type":"function","title":"Example: - Sippet.Message.create_tag/0","doc":"Sippet.Message.create_tag\n    \"lnTMo9Zn\"","ref":"Sippet.Message.html#create_tag/0-example"},{"type":"function","title":"Sippet.Message.delete_header/2","doc":"Deletes all `header` values in `message`.","ref":"Sippet.Message.html#delete_header/2"},{"type":"function","title":"Examples: - Sippet.Message.delete_header/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:content_language, [\"en-US\", \"de-DE\"])\n    ...>   |> Sippet.Message.put_header(:max_forwards, 70)\n    iex> request |> Sippet.Message.delete_header(:content_language)\n    %Sippet.Message{body: nil, headers: %{max_forwards: 70},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#delete_header/2-examples"},{"type":"function","title":"Sippet.Message.delete_header_back/2","doc":"Deletes the last value of `header` in `message`.","ref":"Sippet.Message.html#delete_header_back/2"},{"type":"function","title":"Examples: - Sippet.Message.delete_header_back/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:content_language, [\"en-US\", \"de-DE\"])\n    ...>   |> Sippet.Message.put_header(:max_forwards, 70)\n    iex> request |> Sippet.Message.delete_header_back(:content_language)\n    %Sippet.Message{body: nil,\n     headers: %{content_language: [\"en-US\"], max_forwards: 70},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#delete_header_back/2-examples"},{"type":"function","title":"Sippet.Message.delete_header_front/2","doc":"Deletes the first value of `header` in `message`.","ref":"Sippet.Message.html#delete_header_front/2"},{"type":"function","title":"Examples: - Sippet.Message.delete_header_front/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:content_language, [\"en-US\", \"de-DE\"])\n    ...>   |> Sippet.Message.put_header(:max_forwards, 70)\n    iex> request |> Sippet.Message.delete_header_front(:content_language)\n    %Sippet.Message{body: nil,\n     headers: %{content_language: [\"de-DE\"], max_forwards: 70},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#delete_header_front/2-examples"},{"type":"function","title":"Sippet.Message.drop_headers/2","doc":"Drops all given `headers` from `message`.","ref":"Sippet.Message.html#drop_headers/2"},{"type":"function","title":"Examples: - Sippet.Message.drop_headers/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:content_language, [\"en-US\", \"de-DE\"])\n    ...>   |> Sippet.Message.put_header(:max_forwards, 70)\n    iex> request |> Sippet.Message.drop_headers([:content_language, :max_forwards])\n    %Sippet.Message{body: nil, headers: %{},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#drop_headers/2-examples"},{"type":"function","title":"Sippet.Message.fetch/2","doc":"Fetches the value for a specific `key` in the given `message`.","ref":"Sippet.Message.html#fetch/2"},{"type":"function","title":"Sippet.Message.fetch_header/2","doc":"Fetches all values for a specific `header` and returns it in a tuple.\n\nIf the `header` does not exist, returns `:error`.","ref":"Sippet.Message.html#fetch_header/2"},{"type":"function","title":"Examples: - Sippet.Message.fetch_header/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:content_language, [\"en-US\", \"de-DE\"])\n    ...>   |> Sippet.Message.put_header(:max_forwards, 70)\n    iex> request |> Sippet.Message.fetch_header(:content_language)\n    {:ok, [\"en-US\", \"de-DE\"]}\n    iex> request |> Sippet.Message.fetch_header(:cseq)\n    :error","ref":"Sippet.Message.html#fetch_header/2-examples"},{"type":"function","title":"Sippet.Message.fetch_header!/2","doc":"Fetches all values for a specific `header` in the given `message`, erroring\nout if `message` doesn't contain `header`.\n\nIf `message` contains the given `header`, all corresponding values are\nreturned in a list. If `message` doesn't contain the `header`, a `KeyError`\nexception is raised.","ref":"Sippet.Message.html#fetch_header!/2"},{"type":"function","title":"Sippet.Message.fetch_header_back/2","doc":"Fetches the last value of a specific `header` and returns it in a tuple.\n\nIf the `header` does not exist, or the value is not a list, returns `:error`.\nIf the `header` exists but it is an empty list, returns `{:ok, nil}`.","ref":"Sippet.Message.html#fetch_header_back/2"},{"type":"function","title":"Examples: - Sippet.Message.fetch_header_back/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:content_language, [\"en-US\", \"de-DE\"])\n    ...>   |> Sippet.Message.put_header(:max_forwards, 70)\n    iex> request |> Sippet.Message.fetch_header_back(:content_language)\n    {:ok, \"de-DE\"}\n    iex> request |> Sippet.Message.fetch_header_back(:max_forwards)\n    :error\n    iex> request |> Sippet.Message.fetch_header_back(:cseq)\n    :error","ref":"Sippet.Message.html#fetch_header_back/2-examples"},{"type":"function","title":"Sippet.Message.fetch_header_back!/2","doc":"Fetches the last value of a specific `header` in the given `message`, erroring\nout if `message` doesn't contain `header`.\n\nIf `message` contains the given `header`, the last value is returned, which\nmay be `nil` case the values list is empty. If `message` doesn't contain the\n`header`, a `KeyError` exception is raised.","ref":"Sippet.Message.html#fetch_header_back!/2"},{"type":"function","title":"Sippet.Message.fetch_header_front/2","doc":"Fetches the first value of a specific `header` and returns it in a tuple.\n\nIf the `header` does not exist, or the value is not a list, returns `:error`.\nIf the `header` exists but it is an empty list, returns `{:ok, nil}`.","ref":"Sippet.Message.html#fetch_header_front/2"},{"type":"function","title":"Examples: - Sippet.Message.fetch_header_front/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:content_language, [\"en-US\", \"de-DE\"])\n    ...>   |> Sippet.Message.put_header(:max_forwards, 70)\n    iex> request |> Sippet.Message.fetch_header_front(:content_language)\n    {:ok, \"en-US\"}\n    iex> request |> Sippet.Message.fetch_header_front(:max_forwards)\n    :error\n    iex> request |> Sippet.Message.fetch_header_front(:cseq)\n    :error","ref":"Sippet.Message.html#fetch_header_front/2-examples"},{"type":"function","title":"Sippet.Message.fetch_header_front!/2","doc":"Fetches the first value of a specific `header` in the given `message`, erroring\nout if `message` doesn't contain `header`.\n\nIf `message` contains the given `header`, the first value is returned, which\nmay be `nil` case the values list is empty. If `message` doesn't contain the\n`header`, a `KeyError` exception is raised.","ref":"Sippet.Message.html#fetch_header_front!/2"},{"type":"function","title":"Sippet.Message.get_and_update/3","doc":"Gets the value from key and updates it, all in one pass.\n\nAbout the same as `Map.get_and_update/3` except that this function actually\ndoes not remove the key from the struct case the passed function returns\n`:pop`; it puts `nil` for `:start_line`, `:body` and `:target` ands `%{}` for\nthe `:headers` key.","ref":"Sippet.Message.html#get_and_update/3"},{"type":"function","title":"Sippet.Message.get_and_update_header/3","doc":"Gets the values from `header` and updates it, all in one pass.\n\n`fun` is called with the current values under `header` in `message` (or `nil`\nif `key` is not present in `message`) and must return a two-element tuple:\nthe \"get\" value (the retrieved values, which can be operated on before being\nreturned) and the new values to be stored under `header` in the resulting new\nmessage. `fun` may also return `:pop`, which means all current values shall\nbe removed from `message` and returned (making this function behave like\n`Sippet.Message.pop_header(message, header)`. The returned value is a tuple\nwith the \"get\" value returned by `fun` and a new message with the updated\nvalues under `header`.","ref":"Sippet.Message.html#get_and_update_header/3"},{"type":"function","title":"Sippet.Message.get_and_update_header_back/3","doc":"Gets the last value from `header` and updates it, all in one pass.\n\n`fun` is called with the current last value under `header` in `message` (or\n`nil` if `key` is not present in `message`) and must return a two-element\ntuple: the \"get\" value (the retrieved value, which can be operated on before\nbeing returned) and the new value to be stored under `header` in the\nresulting new message. `fun` may also return `:pop`, which means the current\nvalue shall be removed from `message` and returned (making this function\nbehave like `Sippet.Message.pop_header_back(message, header)`. The returned\nvalue is a tuple with the \"get\" value returned by `fun` and a new message\nwith the updated values under `header`.","ref":"Sippet.Message.html#get_and_update_header_back/3"},{"type":"function","title":"Sippet.Message.get_and_update_header_front/3","doc":"Gets the first value from `header` and updates it, all in one pass.\n\n`fun` is called with the current first value under `header` in `message` (or\n`nil` if `key` is not present in `message`) and must return a two-element\ntuple: the \"get\" value (the retrieved value, which can be operated on before\nbeing returned) and the new value to be stored under `header` in the\nresulting new message. `fun` may also return `:pop`, which means the current\nvalue shall be removed from `message` and returned (making this function\nbehave like `Sippet.Message.pop_header_front(message, header)`. The returned\nvalue is a tuple with the \"get\" value returned by `fun` and a new message\nwith the updated values under `header`.","ref":"Sippet.Message.html#get_and_update_header_front/3"},{"type":"function","title":"Sippet.Message.get_header/3","doc":"Gets all values for a specific `header` in `message`.\n\nIf `header` is present in `message`, then all values are returned in a list.\nOtherwise, `default` is returned (which is `nil` unless specified otherwise).","ref":"Sippet.Message.html#get_header/3"},{"type":"function","title":"Sippet.Message.get_header_back/3","doc":"Gets the last value of a specific `header` in `message`.\n\nIf `header` is present in `message`, then the last value is returned.\nOtherwise, `default` is returned (which is `nil` unless specified otherwise).","ref":"Sippet.Message.html#get_header_back/3"},{"type":"function","title":"Sippet.Message.get_header_front/3","doc":"Gets the first value of a specific `header` in `message`.\n\nIf `header` is present in `message`, then the first value is returned.\nOtherwise, `default` is returned (which is `nil` unless specified otherwise).","ref":"Sippet.Message.html#get_header_front/3"},{"type":"function","title":"Sippet.Message.get_remote/1","doc":"Extracts the remote address and port from an incoming request inspecting the\n`Via` header. If `;rport` is present, use it instead of the topmost `Via`\nport, if `;received` is present, use it instead of the topmost `Via` host.","ref":"Sippet.Message.html#get_remote/1"},{"type":"function","title":"Sippet.Message.has_header?/2","doc":"Returns whether a given `header` exists in the given `message`.","ref":"Sippet.Message.html#has_header?/2"},{"type":"function","title":"Examples: - Sippet.Message.has_header?/2","doc":"iex> request =\n    ...>   Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...>   |> Sippet.Message.put_header(:cseq, {1, :invite})\n    iex> request |> Sippet.Message.has_header?(:cseq)\n    true","ref":"Sippet.Message.html#has_header?/2-examples"},{"type":"function","title":"Sippet.Message.known_methods/0","doc":"Returns a list of all known methods, as a list of uppercase strings.","ref":"Sippet.Message.html#known_methods/0"},{"type":"function","title":"Example: - Sippet.Message.known_methods/0","doc":"iex> Sippet.Message.known_methods()\n    [\"ACK\", \"BYE\", \"CANCEL\", \"INFO\", \"INVITE\", \"MESSAGE\", \"NOTIFY\", \"OPTIONS\",\n     \"PRACK\", \"PUBLISH\", \"PULL\", \"PUSH\", \"REFER\", \"REGISTER\", \"STORE\", \"SUBSCRIBE\",\n     \"UPDATE\"]","ref":"Sippet.Message.html#known_methods/0-example"},{"type":"function","title":"Sippet.Message.known_protocols/0","doc":"Returns a list of all known transport protocols, as a list of uppercase\nstrings.","ref":"Sippet.Message.html#known_protocols/0"},{"type":"function","title":"Example: - Sippet.Message.known_protocols/0","doc":"iex> Sippet.Message.known_protocols()\n    [\"AMQP\", \"DCCP\", \"DTLS\", \"SCTP\", \"STOMP\", \"TCP\", \"TLS\", \"UDP\", \"WS\", \"WSS\"]","ref":"Sippet.Message.html#known_protocols/0-example"},{"type":"function","title":"Sippet.Message.magic_cookie/0","doc":"Returns the RFC 3261 compliance magic cookie, inserted in via-branch\nparameters.","ref":"Sippet.Message.html#magic_cookie/0"},{"type":"function","title":"Example: - Sippet.Message.magic_cookie/0","doc":"iex> Sippet.Message.magic_cookie\n    \"z9hG4bK\"","ref":"Sippet.Message.html#magic_cookie/0-example"},{"type":"function","title":"Sippet.Message.parse/1","doc":"Parses a SIP message header block as received by the transport layer.\n\nIn order to correctly set the message body, you have to verify the\n`:content_length` header; if it exists, it reflects the body size and you\nhave to set it manually on the returned message.","ref":"Sippet.Message.html#parse/1"},{"type":"function","title":"Sippet.Message.parse!/1","doc":"Parses a SIP message header block as received by the transport layer.\n\nRaises if the string is an invalid SIP header.\n\nIn order to correctly set the message body, you have to verify the\n`:content_length` header; if it exists, it reflects the body size and you\nhave to set it manually on the returned message.","ref":"Sippet.Message.html#parse!/1"},{"type":"function","title":"Sippet.Message.pop/3","doc":"Returns and removes the value associated with `key` in `message`.\n\nAbout the same as `Map.pop/3` except that this function actually does not\nremove the key from the struct case the passed function returns `:pop`; it\nputs `nil` for `:start_line`, `:body` and `:target` ands `%{}` for the\n`:headers` key.","ref":"Sippet.Message.html#pop/3"},{"type":"function","title":"Sippet.Message.pop_header/3","doc":"Returns and removes the values associated with `header` in `message`.\n\nIf `header` is present in `message` with values `[value]`, `{[value],\nnew_message}` is returned where `new_message` is the result of removing\n`header` from `message`. If `header` is not present in `message`, `{default,\nmessage}` is returned.","ref":"Sippet.Message.html#pop_header/3"},{"type":"function","title":"Sippet.Message.pop_header_back/3","doc":"Returns and removes the last value associated with `header` in `message`.\n\nIf `header` is present in `message` with values `values`,\n`{List.last(values), new_message}` is returned where `new_message` is the\nresult of removing `List.last(values)` from `header`.  If `header` is not\npresent in `message` or it is an empty list, `{default, message}` is\nreturned. When the `header` results in an empty list, `message` gets updated\nby removing the header.","ref":"Sippet.Message.html#pop_header_back/3"},{"type":"function","title":"Sippet.Message.pop_header_front/3","doc":"Returns and removes the first value associated with `header` in `message`.\n\nIf `header` is present in `message` with values `values`,\n`{List.first(values), new_message}` is returned where `new_message` is the\nresult of removing `List.first(values)` from `header`.  If `header` is not\npresent in `message` or it is an empty list, `{default, message}` is\nreturned. When the `header` results in an empty list, `message` gets updated\nby removing the header.","ref":"Sippet.Message.html#pop_header_front/3"},{"type":"function","title":"Sippet.Message.put_header/3","doc":"Puts the `value` under `header` on the `message`.\n\nIf the header already exists, it will be overridden.","ref":"Sippet.Message.html#put_header/3"},{"type":"function","title":"Examples: - Sippet.Message.put_header/3","doc":"iex> request = Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    iex> request |> Sippet.Message.put_header(:cseq, {1, :invite})\n    %Sippet.Message{body: nil, headers: %{cseq: {1, :invite}},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#put_header/3-examples"},{"type":"function","title":"Sippet.Message.put_header_back/3","doc":"Puts the `value` under `header` on the `message`, as last element.\n\nIf the parameter `value` is `nil`, then the empty list will be appended to\nthe `header`.","ref":"Sippet.Message.html#put_header_back/3"},{"type":"function","title":"Examples: - Sippet.Message.put_header_back/3","doc":"iex> Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...> |> Sippet.Message.put_header_back(:content_language, \"en-US\")\n    ...> |> Sippet.Message.put_header_back(:content_language, \"de-DE\")\n    %Sippet.Message{body: nil, headers: %{content_language: [\"en-US\", \"de-DE\"]},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#put_header_back/3-examples"},{"type":"function","title":"Sippet.Message.put_header_front/3","doc":"Puts the `value` under `header` on the `message`, as front element.\n\nIf the parameter `value` is `nil`, then the empty list will be prefixed to\nthe `header`.","ref":"Sippet.Message.html#put_header_front/3"},{"type":"function","title":"Examples: - Sippet.Message.put_header_front/3","doc":"iex> Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...> |> Sippet.Message.put_header_front(:content_language, \"de-DE\")\n    ...> |> Sippet.Message.put_header_front(:content_language, \"en-US\")\n    %Sippet.Message{body: nil, headers: %{content_language: [\"en-US\", \"de-DE\"]},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#put_header_front/3-examples"},{"type":"function","title":"Sippet.Message.put_new_header/3","doc":"Puts the `value` under `header` on the `message` unless the `header` already\nexists.","ref":"Sippet.Message.html#put_new_header/3"},{"type":"function","title":"Examples: - Sippet.Message.put_new_header/3","doc":"iex> Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...> |> Sippet.Message.put_new_header(:max_forwards, 70)\n    ...> |> Sippet.Message.put_new_header(:max_forwards, 1)\n    %Sippet.Message{body: nil, headers: %{max_forwards: 70},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#put_new_header/3-examples"},{"type":"function","title":"Sippet.Message.put_new_lazy_header/3","doc":"Evaluates `fun` and puts the result under `header` in `message` unless\n`header` is already present.\n\nThis function is useful in case you want to compute the value to put under\n`header` only if `header` is not already present (e.g., the value is\nexpensive to calculate or generally difficult to setup and teardown again).","ref":"Sippet.Message.html#put_new_lazy_header/3"},{"type":"function","title":"Examples: - Sippet.Message.put_new_lazy_header/3","doc":"iex> Sippet.Message.build_request(:invite, \"sip:foo@bar.com\")\n    ...> |> Sippet.Message.put_new_lazy_header(:max_forwards, fn -> 70 end)\n    ...> |> Sippet.Message.put_new_lazy_header(:max_forwards, fn -> 1 end)\n    %Sippet.Message{body: nil, headers: %{max_forwards: 70},\n     start_line: %Sippet.Message.RequestLine{method: :invite,\n      request_uri: %Sippet.URI{authority: \"foo@bar.com\", headers: nil,\n       host: \"bar.com\", parameters: nil, port: 5060, scheme: \"sip\",\n       userinfo: \"foo\"}, version: {2, 0}}, target: nil}","ref":"Sippet.Message.html#put_new_lazy_header/3-examples"},{"type":"function","title":"Sippet.Message.request?/1","doc":"Shortcut to check if the message is a request.","ref":"Sippet.Message.html#request?/1"},{"type":"function","title":"Examples: - Sippet.Message.request?/1","doc":"iex> req = Sippet.Message.build_request :invite, \"sip:foo@bar.com\"\n    iex> req |> Sippet.Message.request?\n    true","ref":"Sippet.Message.html#request?/1-examples"},{"type":"function","title":"Sippet.Message.response?/1","doc":"Shortcut to check if the message is a response.","ref":"Sippet.Message.html#response?/1"},{"type":"function","title":"Examples: - Sippet.Message.response?/1","doc":"iex> resp = Sippet.Message.build_response 200\n    iex> resp |> Sippet.Message.response?\n    true","ref":"Sippet.Message.html#response?/1-examples"},{"type":"function","title":"Sippet.Message.to_iodata/1","doc":"Returns the iodata representation of the given `Sippet.Message` struct.","ref":"Sippet.Message.html#to_iodata/1"},{"type":"function","title":"Sippet.Message.to_method/1","doc":"Converts a string representing a known method into an atom, otherwise as an\nuppercase string.","ref":"Sippet.Message.html#to_method/1"},{"type":"function","title":"Example: - Sippet.Message.to_method/1","doc":"iex> Sippet.Message.to_method(\"INVITE\")\n    :invite\n\n    iex> Sippet.Message.to_method(\"InViTe\")\n    :invite\n\n    iex> Sippet.Message.to_method(\"aaa\")\n    \"AAA\"","ref":"Sippet.Message.html#to_method/1-example"},{"type":"function","title":"Sippet.Message.to_protocol/1","doc":"Converts a string representing a known protocol into an atom, otherwise as an\nuppercase string.","ref":"Sippet.Message.html#to_protocol/1"},{"type":"function","title":"Example: - Sippet.Message.to_protocol/1","doc":"iex> Sippet.Message.to_protocol(\"UDP\")\n    :udp\n\n    iex> Sippet.Message.to_protocol(\"uDp\")\n    :udp\n\n    iex> Sippet.Message.to_protocol(\"aaa\")\n    \"AAA\"","ref":"Sippet.Message.html#to_protocol/1-example"},{"type":"function","title":"Sippet.Message.to_response/2","doc":"Returns a response created from a request, using a given status code.\n\nThe `request` should be a valid SIP request, or an exception will be thrown.\n\nThe `status` parameter can be a `Sippet.Message.StatusLine` struct or an\ninteger in the range `100..699` representing the SIP response status code.\nIn the latter case, a default reason phrase will be obtained from a default\nset; if there's none, then an exception will be raised.","ref":"Sippet.Message.html#to_response/2"},{"type":"function","title":"Example: - Sippet.Message.to_response/2","doc":"request =\n      \"\"\"\n      REGISTER sips:ss2.biloxi.example.com SIP/2.0\n      Via: SIP/2.0/TLS client.biloxi.example.com:5061;branch=z9hG4bKnashds7\n      Max-Forwards: 70\n      From: Bob  ;tag=a73kszlfl\n      To: Bob  \n      Call-ID: 1j9FpLxk3uxtm8tn@biloxi.example.com\n      CSeq: 1 REGISTER\n      Contact:  \n      Content-Length: 0\n      \"\"\" |> Sippet.Message.parse!()\n    request |> Sippet.Message.to_response(200) |> IO.puts\n    SIP/2.0 200 OK\n    Via: SIP/2.0/TLS client.biloxi.example.com:5061;branch=z9hG4bKnashds7\n    To: \"Bob\"  ;tag=K2fizKkV\n    From: \"Bob\"  ;tag=a73kszlfl\n    CSeq: 1 REGISTER\n    Content-Length: 0\n    Call-ID: 1j9FpLxk3uxtm8tn@biloxi.example.com\n\n\n    :ok","ref":"Sippet.Message.html#to_response/2-example"},{"type":"function","title":"Sippet.Message.to_response/3","doc":"Returns a response created from a request, using a given status code and a\ncustom reason phrase.\n\nThe `request` should be a valid SIP request, or an exception will be thrown.\n\nThe `status_code` parameter should be an integer in the range `100..699`\nrepresenting the SIP response status code. A default reason phrase will be\nobtained from a default set; if there's none, then an exception will be\nraised.\n\nThe `reason_phrase` can be any textual representation of the reason phrase\nthe application needs to generate, in binary.","ref":"Sippet.Message.html#to_response/3"},{"type":"function","title":"Example: - Sippet.Message.to_response/3","doc":"request =\n      \"\"\"\n      REGISTER sips:ss2.biloxi.example.com SIP/2.0\n      Via: SIP/2.0/TLS client.biloxi.example.com:5061;branch=z9hG4bKnashds7\n      Max-Forwards: 70\n      From: Bob  ;tag=a73kszlfl\n      To: Bob  \n      Call-ID: 1j9FpLxk3uxtm8tn@biloxi.example.com\n      CSeq: 1 REGISTER\n      Contact:  \n      Content-Length: 0\n      \"\"\" |> Sippet.Message.parse!()\n    request |> Sippet.Message.to_response(400, \"Bad Lorem Ipsum\") |> IO.puts\n    SIP/2.0 400 Bad Lorem Ipsum\n    Via: SIP/2.0/TLS client.biloxi.example.com:5061;branch=z9hG4bKnashds7\n    To: \"Bob\"  ;tag=K2fizKkV\n    From: \"Bob\"  ;tag=a73kszlfl\n    CSeq: 1 REGISTER\n    Content-Length: 0\n    Call-ID: 1j9FpLxk3uxtm8tn@biloxi.example.com\n\n\n    :ok","ref":"Sippet.Message.html#to_response/3-example"},{"type":"function","title":"Sippet.Message.to_string/1","doc":"Returns the string representation of the given `Sippet.Message` struct.","ref":"Sippet.Message.html#to_string/1"},{"type":"function","title":"Sippet.Message.update_header/4","doc":"Updates the `header` in `message` with the given function.\n\nIf `header` is present in `message` with value `value`, `fun` is invoked\nwith argument `value` and its result is used as the new value of `header`.\nIf `header` is not present in `message`, `initial` is inserted as the value\nof `header`.","ref":"Sippet.Message.html#update_header/4"},{"type":"function","title":"Sippet.Message.update_header_back/4","doc":"Updates the last `header` value in `message` with the given function.\n\nIf `header` is present in `message` with value `[value]`, `fun` is invoked\nwith for last element of `[value]` and its result is used as the new value of\n`header` back.  If `header` is not present in `message`, or it is an empty\nlist, `initial` is inserted as the single value of `header`.","ref":"Sippet.Message.html#update_header_back/4"},{"type":"function","title":"Sippet.Message.update_header_front/4","doc":"Updates the first `header` value in `message` with the given function.\n\nIf `header` is present in `message` with value `[value]`, `fun` is invoked\nwith for first element of `[value]` and its result is used as the new value\nof `header` front.  If `header` is not present in `message`, or it is an empty\nlist, `initial` is inserted as the single value of `header`.","ref":"Sippet.Message.html#update_header_front/4"},{"type":"function","title":"Sippet.Message.valid?/1","doc":"Checks whether a message is valid.","ref":"Sippet.Message.html#valid?/1"},{"type":"function","title":"Sippet.Message.valid?/2","doc":"Checks whether a message is valid, also checking if it corresponds to the\nindicated incoming transport tuple `{protocol, host, port}`.","ref":"Sippet.Message.html#valid?/2"},{"type":"function","title":"Sippet.Message.validate/1","doc":"Validates if a message is valid, returning errors if found.","ref":"Sippet.Message.html#validate/1"},{"type":"function","title":"Sippet.Message.validate/2","doc":"Validates if a message is valid, also checking if it corresponds to the\nindicated incoming transport tuple `{protocol, host, port}`. It returns the\nerror if found.","ref":"Sippet.Message.html#validate/2"},{"type":"type","title":"Sippet.Message.auth_params/0","doc":"","ref":"Sippet.Message.html#t:auth_params/0"},{"type":"type","title":"Sippet.Message.header/0","doc":"","ref":"Sippet.Message.html#t:header/0"},{"type":"type","title":"Sippet.Message.headers/0","doc":"","ref":"Sippet.Message.html#t:headers/0"},{"type":"type","title":"Sippet.Message.method/0","doc":"","ref":"Sippet.Message.html#t:method/0"},{"type":"type","title":"Sippet.Message.multiple_value/0","doc":"","ref":"Sippet.Message.html#t:multiple_value/0"},{"type":"type","title":"Sippet.Message.name_uri_params/0","doc":"","ref":"Sippet.Message.html#t:name_uri_params/0"},{"type":"type","title":"Sippet.Message.params/0","doc":"","ref":"Sippet.Message.html#t:params/0"},{"type":"type","title":"Sippet.Message.protocol/0","doc":"","ref":"Sippet.Message.html#t:protocol/0"},{"type":"type","title":"Sippet.Message.request/0","doc":"","ref":"Sippet.Message.html#t:request/0"},{"type":"type","title":"Sippet.Message.response/0","doc":"","ref":"Sippet.Message.html#t:response/0"},{"type":"type","title":"Sippet.Message.single_value/0","doc":"","ref":"Sippet.Message.html#t:single_value/0"},{"type":"type","title":"Sippet.Message.t/0","doc":"","ref":"Sippet.Message.html#t:t/0"},{"type":"type","title":"Sippet.Message.token/0","doc":"","ref":"Sippet.Message.html#t:token/0"},{"type":"type","title":"Sippet.Message.token_params/0","doc":"","ref":"Sippet.Message.html#t:token_params/0"},{"type":"type","title":"Sippet.Message.type_subtype_params/0","doc":"","ref":"Sippet.Message.html#t:type_subtype_params/0"},{"type":"type","title":"Sippet.Message.uri/0","doc":"","ref":"Sippet.Message.html#t:uri/0"},{"type":"type","title":"Sippet.Message.uri_params/0","doc":"","ref":"Sippet.Message.html#t:uri_params/0"},{"type":"type","title":"Sippet.Message.value/0","doc":"","ref":"Sippet.Message.html#t:value/0"},{"type":"type","title":"Sippet.Message.via_value/0","doc":"","ref":"Sippet.Message.html#t:via_value/0"},{"type":"module","title":"Sippet.Message.RequestLine","doc":"A SIP Request-Line struct, composed by the Method, Request-URI and\nSIP-Version.\n\nThe `start_line` of requests are represented by this struct. The RFC 3261\nrepresents the Request-Line as:\n\n    Request-Line  =  Method SP Request-URI SP SIP-Version CRLF\n\nThe above `Method` is represented by atoms, when the method is a known one,\nor by binaries, when the method is unknown. Known ones are `:ack`, `:invite`,\n`:register`, `:cancel`, `:message` and all others returned by the function\n`Sippet.Message.known_methods/0`.\n\nThe `Request-URI` is represented by a `Sippet.URI` struct, breaking down the\nSIP-URI in more useful parts for processing.\n\nThe `SIP-Version` is a `{major, minor}` tuple, which assumes the value\n`{2, 0}` in standard implementations.","ref":"Sippet.Message.RequestLine.html"},{"type":"function","title":"Sippet.Message.RequestLine.new/2","doc":"Creates a Request-Line struct.\n\nThe version will assume the default value `{2, 0}`.","ref":"Sippet.Message.RequestLine.html#new/2"},{"type":"function","title":"Sippet.Message.RequestLine.to_iodata/1","doc":"Returns an iodata which corresponds to the text representation of the given\nRequest-Line.\n\nIt does not includes an ending line CRLF.","ref":"Sippet.Message.RequestLine.html#to_iodata/1"},{"type":"function","title":"Sippet.Message.RequestLine.to_string/1","doc":"Returns a binary which corresponds to the text representation of the given\nRequest-Line.\n\nIt does not includes an ending line CRLF.","ref":"Sippet.Message.RequestLine.html#to_string/1"},{"type":"type","title":"Sippet.Message.RequestLine.method/0","doc":"","ref":"Sippet.Message.RequestLine.html#t:method/0"},{"type":"type","title":"Sippet.Message.RequestLine.t/0","doc":"","ref":"Sippet.Message.RequestLine.html#t:t/0"},{"type":"type","title":"Sippet.Message.RequestLine.uri/0","doc":"","ref":"Sippet.Message.RequestLine.html#t:uri/0"},{"type":"type","title":"Sippet.Message.RequestLine.version/0","doc":"","ref":"Sippet.Message.RequestLine.html#t:version/0"},{"type":"module","title":"Sippet.Message.StatusLine","doc":"A SIP Status-Line struct, composed by the SIP-Version, Status-Code and the\nReason-Phrase.\n\nThe `start_line` of responses are represented by this struct. The RFC 3261\nrepresents the Status-Line as:\n\n    Status-Line  =  SIP-Version SP Status-Code SP Reason-Phrase CRLF\n\nThe above `SIP-Version` is represented by a `{major, minor}` tuple, which\nassumes the value `{2, 0}` in standard implementations.\n\nThe `Status-Code` is a 3-digit integer in the interval 100-699 indicating the\noutcome of an attempt to understand and satisfy a request.\n\nThe `Reason-Phrase` is a binary representing a short textual description of\nthe `Status-Code`.\n\nThe `Status-Code` is intended for use by automata, whereas the\n`Reason-Phrase` is intended for the human user.","ref":"Sippet.Message.StatusLine.html"},{"type":"function","title":"Sippet.Message.StatusLine.default_reason/1","doc":"Returns a binary representing the default reason phrase for the given\n`status_code`.\n\nIf the `status_code` does not have a corresponding default reason phrase,\nreturns `nil`.","ref":"Sippet.Message.StatusLine.html#default_reason/1"},{"type":"function","title":"Examples - Sippet.Message.StatusLine.default_reason/1","doc":"iex> Sippet.Message.StatusLine.default_reason(202)\n    \"Accepted\"\n    iex> Sippet.Message.StatusLine.default_reason(499)\n    nil","ref":"Sippet.Message.StatusLine.html#default_reason/1-examples"},{"type":"function","title":"Sippet.Message.StatusLine.default_reason!/1","doc":"Returns a binary representing the default reason phrase for the given\n`status_code`.\n\nIf the `status_code` does not have a corresponding default reason phrase,\nthrows an exception.","ref":"Sippet.Message.StatusLine.html#default_reason!/1"},{"type":"function","title":"Examples - Sippet.Message.StatusLine.default_reason!/1","doc":"iex> Sippet.Message.StatusLine.default_reason!(202)\n    \"Accepted\"\n    iex> Sippet.Message.StatusLine.default_reason!(499)\n    ** (ArgumentError) status code 499 does not have a default reason phrase","ref":"Sippet.Message.StatusLine.html#default_reason!/1-examples"},{"type":"function","title":"Sippet.Message.StatusLine.new/1","doc":"Returns a Status-Line struct.\n\nThe `reason_phrase` is obtained from default values.\n\nThe function will throw an exception if the `status_code` is not in the valid\nrange `100..699` or if the `status_code` does not have a default reason\nphrase.\n\nThe version will assume the default value `{2, 0}`.","ref":"Sippet.Message.StatusLine.html#new/1"},{"type":"function","title":"Examples - Sippet.Message.StatusLine.new/1","doc":"iex> Sippet.Message.StatusLine.new(400)\n    %Sippet.Message.StatusLine{reason_phrase: \"Bad Request\", status_code: 400,\n     version: {2, 0}}","ref":"Sippet.Message.StatusLine.html#new/1-examples"},{"type":"function","title":"Sippet.Message.StatusLine.new/2","doc":"Creates a Status-Line struct using a given reason phrase.\n\nIn this function, the `reason_phrase` can be anything the application wants.\n\nThe function will throw an exception if the `status_code` is not in the valid\nrange `100..699`.\n\nThe version will assume the default value `{2, 0}`.","ref":"Sippet.Message.StatusLine.html#new/2"},{"type":"function","title":"Examples - Sippet.Message.StatusLine.new/2","doc":"iex> Sippet.Message.StatusLine.new(499, \"Foobar\")\n    %Sippet.Message.StatusLine{reason_phrase: \"Foobar\", status_code: 499,\n     version: {2, 0}}","ref":"Sippet.Message.StatusLine.html#new/2-examples"},{"type":"function","title":"Sippet.Message.StatusLine.status_code_class/1","doc":"Returns an integer representing the status code class in the range `[1, 6]`.","ref":"Sippet.Message.StatusLine.html#status_code_class/1"},{"type":"function","title":"Examples - Sippet.Message.StatusLine.status_code_class/1","doc":"iex> alias Sippet.Message.StatusLine\n    iex> StatusLine.new(202) |> StatusLine.status_code_class()\n    2","ref":"Sippet.Message.StatusLine.html#status_code_class/1-examples"},{"type":"function","title":"Sippet.Message.StatusLine.to_iodata/1","doc":"Returns an iodata which corresponds to the text representation of the given\nStatus-Line.\n\nIt does not includes an ending line CRLF.","ref":"Sippet.Message.StatusLine.html#to_iodata/1"},{"type":"function","title":"Examples - Sippet.Message.StatusLine.to_iodata/1","doc":"iex> alias Sippet.StatusLine\n  iex> StatusLine.new(202) |> StatusLine.to_iodata\n  [\"SIP/\", \"2\", \".\", \"0\", \" \", \"202\", \" \", \"Accepted\"]","ref":"Sippet.Message.StatusLine.html#to_iodata/1-examples"},{"type":"function","title":"Sippet.Message.StatusLine.to_string/1","doc":"Returns a binary which corresponds to the text representation of the given\nStatus-Line.\n\nIt does not includes an ending line CRLF.","ref":"Sippet.Message.StatusLine.html#to_string/1"},{"type":"function","title":"Examples - Sippet.Message.StatusLine.to_string/1","doc":"iex> alias Sippet.StatusLine\n  iex> StatusLine.new(202) |> StatusLine.to_string\n  \"SIP/2.0 202 Accepted\"","ref":"Sippet.Message.StatusLine.html#to_string/1-examples"},{"type":"type","title":"Sippet.Message.StatusLine.status_code/0","doc":"","ref":"Sippet.Message.StatusLine.html#t:status_code/0"},{"type":"type","title":"Sippet.Message.StatusLine.t/0","doc":"","ref":"Sippet.Message.StatusLine.html#t:t/0"},{"type":"type","title":"Sippet.Message.StatusLine.version/0","doc":"","ref":"Sippet.Message.StatusLine.html#t:version/0"},{"type":"module","title":"Sippet.Parser","doc":"Communicates with the C++ NIF parser in order to parse the SIP header.\n\nThe C++ NIF module was created to optimize the parsing.","ref":"Sippet.Parser.html"},{"type":"function","title":"Sippet.Parser.init/0","doc":"Initializes and loads the C++ NIF module.","ref":"Sippet.Parser.html#init/0"},{"type":"function","title":"Sippet.Parser.parse/1","doc":"Parses the SIP message into an Erlang-like map.\n\nThe `Sippet.Message` module translates the result into an Elixir-like struct.","ref":"Sippet.Parser.html#parse/1"},{"type":"module","title":"Sippet.Transactions.Client.Key","doc":"Defines a key in which client transactions are uniquely identified.","ref":"Sippet.Transactions.Client.Key.html"},{"type":"function","title":"Sippet.Transactions.Client.Key.new/1","doc":"Create a client transaction identifier from an outgoing request or an\nincoming response. If they are related, they will be equal.","ref":"Sippet.Transactions.Client.Key.html#new/1"},{"type":"function","title":"Sippet.Transactions.Client.Key.new/2","doc":"Create a client transaction identifier.","ref":"Sippet.Transactions.Client.Key.html#new/2"},{"type":"type","title":"Sippet.Transactions.Client.Key.branch/0","doc":"The topmost Via header branch parameter","ref":"Sippet.Transactions.Client.Key.html#t:branch/0"},{"type":"type","title":"Sippet.Transactions.Client.Key.t/0","doc":"","ref":"Sippet.Transactions.Client.Key.html#t:t/0"},{"type":"module","title":"Sippet.Transactions.Server.Key","doc":"Defines a key in which server transactions are uniquely identified.","ref":"Sippet.Transactions.Server.Key.html"},{"type":"function","title":"Sippet.Transactions.Server.Key.new/1","doc":"Creates a server transaction identifier from an incoming request or an\noutgoing response. If they are related, they will be equal.","ref":"Sippet.Transactions.Server.Key.html#new/1"},{"type":"function","title":"Sippet.Transactions.Server.Key.new/3","doc":"Creates a server transaction identifier.","ref":"Sippet.Transactions.Server.Key.html#new/3"},{"type":"type","title":"Sippet.Transactions.Server.Key.branch/0","doc":"The topmost Via header branch parameter","ref":"Sippet.Transactions.Server.Key.html#t:branch/0"},{"type":"type","title":"Sippet.Transactions.Server.Key.sentby/0","doc":"The topmost Via header sent-by parameter","ref":"Sippet.Transactions.Server.Key.html#t:sentby/0"},{"type":"type","title":"Sippet.Transactions.Server.Key.t/0","doc":"","ref":"Sippet.Transactions.Server.Key.html#t:t/0"},{"type":"module","title":"Sippet.Transports.UDP","doc":"Implements an UDP transport.\n\nThe UDP transport consists basically in a single listening and sending\nprocess, this implementation itself.\n\nThis process creates an UDP socket and keeps listening for datagrams in\nactive mode. Its job is to forward the datagrams to the processing receiver\ndefined in `Sippet.Transports.Receiver`.","ref":"Sippet.Transports.UDP.html"},{"type":"function","title":"Sippet.Transports.UDP.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Sippet.Transports.UDP.html#child_spec/1"},{"type":"function","title":"Sippet.Transports.UDP.start_link/1","doc":"Starts the UDP transport.","ref":"Sippet.Transports.UDP.html#start_link/1"}],"content_type":"text/markdown"}